Skip to main content

Autumn8 CLI

Autumn8 CLI is a toolkit, which allows you to easily interact programatically with the Autumn8's ML service, AutoDL.

Documentation

For the official, up-to-date documentation for the CLI, go here:

DOCUMENTATION

Example Usage

$ autumn8-cli --help
Usage: autumn8-cli [OPTIONS] COMMAND [ARGS]...

Options:
  --version  Show the version and exit.
  --help     Show this message and exit.

Commands:
  delete-model          Delete model from AutoDL
  deploy                Deploy a model from AutoDL onto cloud.
  get-model             Get model data from AutoDL
  list-deployments      List running deployments.
  login                 Store API credentials for the CLI for future use.
  run-docker            Run an inference on a given Docker image by...
  run-inference         Run an inference on a given deployment
  submit-checkpoint     Submit checkpoint to AutoDL
  submit-model          Submit a model to AutoDL.
  terminate-deployment  Terminate a running deployment.
  test-connection       Test AutoDL connection with the current API key.

Logging In

To use the CLI - as a prerequisite, you'll have to log in into autodl.autumn8.ai and generate an API key for you CLI from your Profile page.

Follow the instructions on https://autodl.autumn8.ai/profile to authenticate your CLI.

$ autumn8-cli login --user_id $YOUR_USER_ID --api_key $YOUR_API_KEY

Uploading Models

$ autumn8-cli submit-model --help
Usage: autumn8-cli submit-model [OPTIONS] MODEL_FILEPATH_OR_URL
                                [MODEL_SCRIPT_ARGS]...

  Submit a model to AutoDL.

Options:
  -n, --name TEXT                 Name of the model to be used in AutoDL.
  -t, --quantization, --quants [FP32|FP16|INT8]
                                  Quantization for the model.
  --input_dims TEXT               The model input dimensions, specified as a
                                  JSON array.
  -w, --max_upload_workers INTEGER
                                  The count of workers to use for multipart
                                  uploads; defaults to 4.
  --input_file TEXT               The model input filepath.
  -y, --yes                       Skip all confirmation input from the user.
  --skip_inputs                   Don't ask about inputs, let AutoDL try to
                                  infer them.
  -o, --organization_id, --org_id INTEGER
                                  The ID of the Organization to use
  -q, --quiet                     Skip additional logging, printing only
                                  necessary info
  -g, --group_id TEXT             The ID of the model group to add the model
                                  to.
  --help                          Show this message and exit.

Let's download an example input for our model:

$ wget -O ./whisper.json \
    https://autodl-public-assets.s3.amazonaws.com/sample-inputs/whisper.json

... and upload it to the Autumn8 AutoDL service - run:

$ autumn8-cli submit-model \
    --input_file ./whisper.json \
    https://autodl-public-assets.s3.amazonaws.com/sample-models/whisper.mar

then follow the on-screen instructions.

Deploying Models

$ autumn8-cli deploy --help
Usage: autumn8-cli deploy [OPTIONS]

  Deploy a model from AutoDL onto cloud.

Options:
  -hw, -t, --machine_type TEXT    Server type to use for the deployment
  -o, --organization_id, --org_id INTEGER
                                  The ID of the Organization to use
  -q, --quiet                     Skip additional logging, printing only
                                  necessary info
  -m, --model_id INTEGER          Model ID to deploy
  -s, --schedule / -i, --immediate
                                  Schedule the deployment to run in the future
  --schedule_on TEXT              Schedule the deployment on given date
  --deployment_id TEXT            Update an existing deployment, retaining its
                                  URL
  -b, --deploy_best [latency|throughput|cost_performance|total_energy|emissions]
                                  Let Autumn8 pick the server type
                                  automatically for the deployment
  -c, --cloud_provider [a8f|gcp|aws|None|Amazon|Google Cloud Platform|Oracle|Azure|Autumn8]
                                  Cloud provider to use
  --help                          Show this message and exit.

We can roll out a model deployment with:

$ autumn8-cli deploy -c a8f -m $MODEL_ID -hw c5.large --org_id $YOUR_ORG_ID

Metadata

Release files for autumn8 2.0.8

For a detailed explanation of source distributions (sdists) and built distributions (wheels), please see the package formats documentation.

Source distribution (sdist)

Source distribution for autumn8 2.0.8
File Size Uploaded Provenance
autumn8-2.0.8.tar.gz 53.8 kB Without provenance Details

Built distribution (wheel)

Table of built distributions (wheels) for autumn8 2.0.8
File Interpreter ABI Platform
autumn8-2.0.8-py3-none-any.whl Python 3 none any Details

Total release size: 116.3 kB

Release files / autumn8-2.0.8.tar.gz

Download URL autumn8-2.0.8.tar.gz
Size 53.8 kB
Tags Source
SHA-256 checksum
How to use checksums
434c66d0bee79b6e0f6bc6e90e18eb8ff4a32c1dd49232d15cd986e1f6d30681
BLAKE2b-256 checksum
How to use checksums
c79c9bcdb5dbf81824a1c8ef1d0a906e4208c4cb4b6dadf7c8a4b25c26e21279
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/4.0.2 CPython/3.8.14

Release files / autumn8-2.0.8-py3-none-any.whl

Download URL autumn8-2.0.8-py3-none-any.whl
Size 62.5 kB
Tags Python 3
SHA-256 checksum
How to use checksums
867873b89efc3b1dca71235747e6691e6e21310748596ac26651d54ac3f9806f
BLAKE2b-256 checksum
How to use checksums
cc556b0a731360b2c59b84e2f0c6cb91e5d265eb0dbfbf95f9b8bd3396e9c419
Upload date
Uploaded using Trusted Publishing?
What is trusted publishing?
No
Uploaded via twine/4.0.2 CPython/3.8.14

Security for autumn8 2.0.8

Provenance

Provenance describes where a file came from. On PyPI, provenance is shared via attestations, which provide a verifiable record of the build or publishing details. View details, limitations and caveats.

No provenance found

None of the files in this release were uploaded with provenance metadata.

A note on package security

PyPI is a repository for distributing packages, not a service for auditing them. While third-party security researchers and our staff do their best to detect and remove malicious packages, PyPI cannot guarantee the quality, security or suitability of any given package.

Release history Release notifications | RSS feed

This release

2.0.8 This release

2 release files No provenance

Anthropic, PBC Visionary sponsor Bloomberg Visionary sponsor Hudson River Trading Visionary sponsor Meta Visionary sponsor NVIDIA Visionary sponsor Microsoft Sustainability sponsor Depot Continuous Integration AWS Cloud computing and Security Sponsor Datadog Monitoring Fastly CDN Google Download Analytics Sentry Error logging StatusPage Status page